@@ -53,9 +53,10 @@
 #  include "config.h"
 #endif
 
+#include "gstvorbiselements.h"
 #include "gstvorbisparse.h"
 
-GST_DEBUG_CATEGORY_EXTERN (vorbisparse_debug);
+GST_DEBUG_CATEGORY_STATIC (vorbisparse_debug);
 #define GST_CAT_DEFAULT vorbisparse_debug
 
 static GstStaticPadTemplate vorbis_parse_sink_factory =
@@ -74,6 +75,11 @@ GST_STATIC_PAD_TEMPLATE ("src",
 
 #define gst_vorbis_parse_parent_class parent_class
 G_DEFINE_TYPE (GstVorbisParse, gst_vorbis_parse, GST_TYPE_ELEMENT);
+GST_ELEMENT_REGISTER_DEFINE_WITH_CODE (vorbisparse, "vorbisparse",
+    GST_RANK_NONE, GST_TYPE_VORBIS_PARSE,
+    GST_DEBUG_CATEGORY_INIT (vorbisparse_debug, "vorbisparse", 0,
+        "vorbis parsing element");
+    vorbis_element_init (plugin));
 
 static GstFlowReturn vorbis_parse_chain (GstPad * pad, GstObject * parent,
     GstBuffer * buffer);
@@ -178,7 +184,21 @@ vorbis_parse_drain_event_queue (GstVorbisParse * parse)
   }
 }
 
-static void
+static gboolean
+vorbis_parse_have_header_packet (GstVorbisParse * parse, guint8 hdr_id)
+{
+  guint8 hdr;
+  GList *l;
+
+  for (l = parse->streamheader; l != NULL; l = l->next) {
+    if (gst_buffer_extract (l->data, 0, &hdr, 1) == 1 && hdr == hdr_id)
+      return TRUE;
+  }
+
+  return FALSE;
+}
+
+static gboolean
 vorbis_parse_push_headers (GstVorbisParse * parse)
 {
   /* mark and put on caps */
@@ -186,6 +206,20 @@ vorbis_parse_push_headers (GstVorbisParse * parse)
   GstBuffer *outbuf, *outbuf1, *outbuf2, *outbuf3;
   ogg_packet packet;
   GstMapInfo map;
+  const gchar *hdr_name;
+
+  /* Check we have enough header packets, and the right ones */
+  hdr_name = "identification";
+  if (!vorbis_parse_have_header_packet (parse, 1))
+    goto missing_header;
+
+  hdr_name = "comment";
+  if (!vorbis_parse_have_header_packet (parse, 3))
+    goto missing_header;
+
+  hdr_name = "setup";
+  if (!vorbis_parse_have_header_packet (parse, 5))
+    goto missing_header;
 
   outbuf = GST_BUFFER_CAST (parse->streamheader->data);
   gst_buffer_map (outbuf, &map, GST_MAP_READ);
@@ -244,6 +278,15 @@ vorbis_parse_push_headers (GstVorbisParse * parse)
 
   g_list_free (parse->streamheader);
   parse->streamheader = NULL;
+  return TRUE;
+
+/* ERRORS */
+missing_header:
+  {
+    GST_ELEMENT_ERROR (parse, STREAM, DECODE, (NULL),
+        ("Vorbis stream is missing %s header", hdr_name));
+    return FALSE;
+  }
 }
 
 static void
@@ -413,12 +456,17 @@ vorbis_parse_parse_packet (GstVorbisParse * parse, GstBuffer * buf)
   } else {
     /* data packet, push the headers we collected before */
     if (!parse->streamheader_sent) {
-      vorbis_parse_push_headers (parse);
+      if (!vorbis_parse_push_headers (parse)) {
+        ret = GST_FLOW_ERROR;
+        goto out;
+      }
       parse->streamheader_sent = TRUE;
     }
     ret = vorbis_parse_queue_buffer (parse, buf);
   }
 
+out:
+
   return ret;
 }
 
