@@ -170,9 +170,7 @@ gst_gl_context_cocoa_dump_pixel_format (CGLPixelFormatObj fmt)
 CGLPixelFormatObj
 gst_gl_context_cocoa_get_pixel_format (GstGLContextCocoa *context)
 {
-  if (context->priv->pixel_format)
-    return CGLRetainPixelFormat (context->priv->pixel_format);
-  return NULL;
+  return context->priv->pixel_format;
 }
 
 static GstStructure *
@@ -264,13 +262,12 @@ gst_gl_context_cocoa_create_context (GstGLContext *context, GstGLAPI gl_api,
     gint profile;
 
     fmt = CGLGetPixelFormat (priv->external_gl_context);
-    CGLRetainPixelFormat (fmt);
 
 #if MAC_OS_X_VERSION_MIN_REQUIRED >= 1070
     /* core profile is only available in >= 10.7 */
     if (kCGLNoError == CGLDescribePixelFormat (fmt, 0, kCGLPFAOpenGLProfile,
           &profile)) {
-      if (profile >= kCGLOGLPVersion_3_2_Core) {
+      if (profile == kCGLOGLPVersion_3_2_Core) {
         context_api = GST_GL_API_OPENGL3;
       } else {
         context_api =GST_GL_API_OPENGL;
@@ -310,14 +307,13 @@ gst_gl_context_cocoa_create_context (GstGLContext *context, GstGLAPI gl_api,
   if (ret != kCGLNoError) {
     g_set_error (error, GST_GL_CONTEXT_ERROR, GST_GL_CONTEXT_ERROR_CREATE_CONTEXT,
         "failed to create context: %s", CGLErrorString (ret));
-    CGLReleasePixelFormat (fmt);
     goto error;
   }
 
   context_cocoa->priv->pixel_format = fmt;
   context_cocoa->priv->gl_context = glContext;
 
-  _gst_gl_invoke_on_main ((GstGLWindowCB) gst_gl_window_cocoa_create_window,
+  _invoke_on_main ((GstGLWindowCB) gst_gl_window_cocoa_create_window,
       gst_object_ref (window_cocoa), (GDestroyNotify) gst_object_unref);
 
   if (!context_cocoa->priv->gl_context) {
@@ -356,17 +352,7 @@ gst_gl_context_cocoa_swap_buffers (GstGLContext * context)
 static void
 gst_gl_context_cocoa_destroy_context (GstGLContext *context)
 {
-  GstGLContextCocoa *context_cocoa = GST_GL_CONTEXT_COCOA (context);
-
-  if (context_cocoa->priv->gl_context != NULL) {
-    CGLDestroyContext(context_cocoa->priv->gl_context);
-    context_cocoa->priv->gl_context = NULL;
-  }
-
-  if (context_cocoa->priv->pixel_format) {
-    CGLReleasePixelFormat(context_cocoa->priv->pixel_format);
-    context_cocoa->priv->pixel_format = NULL;
-  }
+  /* FIXME: Need to release context and other things? */
 }
 
 static guintptr
